/* eslint-disable no-console */
import ZdCalendar from '@/components/calendarTes/ZdCalendar';
import {
  Select, TextInput, Date as DateInput, Time,
} from '@zeedhi/common';
import {
  Http, IDictionary, Loader, Metadata,
} from '@zeedhi/core';

export class FCMCalendarController {
  public modalController = Loader.getInstance('ModalTask');

  public setUnidade({ component }:{ component:Select }) {
    Http.post('/LocalsForCalendar', { id: 1 }).then((response: IDictionary) => {
      response.data.dataset.locals.forEach((element: IDictionary) => {
        component.datasource.data.push({
          name: element.NMLOCALCLIENTE,
          value: element.NRLOCALCLIENTE,
        });
      });
    });
  }

  public setLocal({ component }:{ component:Select }) {
    Http.post('/LocalsForCalendar', { id: 3 }).then((response: IDictionary) => {
      response.data.dataset.locals.forEach((element: IDictionary) => {
        component.datasource.data.push({
          name: element.NMLOCALCLIENTE,
          value: element.NRLOCALCLIENTE,
        });
      });
    });
  }

  public setSector({ component }:{ component:Select }) {
    Http.get('Sectors').then((response: IDictionary) => {
      response.data.dataset.Sectors.forEach((element: IDictionary) => {
        component.datasource.data.push({
          name: element.NMSETOR,
          value: element.NRSETOR,
        });
      });
    });
  }

  public setLocalTypes({ component }:{ component:Select }) {
    Http.get('/LocalTypes').then((response: IDictionary) => {
      response.data.dataset.typeLocal.forEach((element: IDictionary) => {
        component.datasource.data.push({
          name: element.NMTIPOLOCALCLI,
          value: element.NRTIPOLOCALCLI,
        });
      });
    });
  }

  public setTaskTypes({ component }:{ component:Select }) {
    Http.get('/TaskTypes').then((response: IDictionary) => {
      response.data.dataset.taskTypes.forEach((element: IDictionary) => {
        component.datasource.data.push({
          name: element.NMATIVIDADE,
          value: element.NRATIVIDADE,
        });
      });
    });
  }

  get getUnidade() {
    return Metadata.getInstance<Select>('SelectUnidade').value;
  }

  get getLocal() {
    return Metadata.getInstance<Select>('SelectLocal').value;
  }

  get getSector() {
    return Metadata.getInstance<Select>('SelectSetor').value;
  }

  get getLocalTypes() {
    return Metadata.getInstance<Select>('SelectTipoTarefa').value;
  }

  get getTaskTypes() {
    return Metadata.getInstance<Select>('SelectTipoLocal').value;
  }

  public filterDate() {
    const component = Metadata.getInstance<ZdCalendar>('CalendarEvents');
    this.getDados({ component });
  }

  public getDados({ component }:{ component:ZdCalendar }) {
    component.eventos = [];
    Http.get(`/InspectionTask?nr=${localStorage.getItem('UserLogado')}&start=${component.startPeriod}&finish=${component.endPeriod}&uni=${this.getUnidade}&loc=${this.getLocal}&sec=${this.getSector}&lct=${this.getLocalTypes}&tst=${this.getTaskTypes}`).then((response: IDictionary) => {
      response.data.dataset.inspectionTask.forEach((element: IDictionary) => {
        component.eventos.push({
          name: `Vistoria-${element.NMGERENCIAMENTOCHK}`,
          start: element.DTHORAAGEND,
          end: element.DTHRFINALAGEND,
          color: (this.getUnidade === null) ? element.DSCORIDLOCAL : element.CORATIVIDADE,
          timed: false,
        });
      });
    });
    Http.get(`/Task?nr=${localStorage.getItem('UserLogado')}&start=${component.startPeriod}&finish=${component.endPeriod}&uni=${this.getUnidade}&loc=${this.getLocal}&sec=${this.getSector}&lct=${this.getLocalTypes}&tst=${this.getTaskTypes}`).then((response: IDictionary) => {
      response.data.dataset.task.forEach((element: IDictionary) => {
        component.eventos.push({
          name: element.NMCHECKLISTAGEND,
          start: element.DTHORAAGEND,
          end: element.DTHRFINALAGEND,
          color: (this.getUnidade === null) ? element.DSCORIDLOCAL : element.CORATIVIDADE,
          timed: false,
        });
      });
    });
  }

  public clickOnEvent(dados: any) {
    this.modalController.openHeaderFooterModal();
    let complemento = '';
    if ((dados.name).indexOf('Vistoria-') > -1) {
      complemento = 'Vistoria-';
    }
    Http.get(`/infoTask?nr=${localStorage.getItem('UserLogado')}&name=${(dados.name).replace(complemento, '')}&start=${dados.start}&end=${dados.end}`).then((response: IDictionary) => {
      const db = response.data.dataset.task[0];
      Metadata.getInstance<TextInput>('InfoLocal').value = `${complemento}${db.NMLOCALCLIENTE}`;
      Metadata.getInstance<TextInput>('InfoLocalType').value = db.NMTIPOLOCALCLI;
      Metadata.getInstance<TextInput>('InfoService').value = '';
      Metadata.getInstance<TextInput>('InfoFunc').value = db.NMFUNCIONARIO;
      [Metadata.getInstance<DateInput>('infoData').value, Metadata.getInstance<Time>('InfoHour').value] = db.DTHORAAGEND.split(' ');
      Metadata.getInstance<TextInput>('InfoDuracao').value = `${((new Date(db.DTHRFINALAGEND)).getTime() - (new Date(db.DTHORAAGEND)).getTime()) / 60000} min`;
      /* eslint-disable no-console */
      console.log(complemento);
      // Duração em minutos = ((new Date()).getTime() - (new Date()).getTime())/60000
    });
  }
}
